@@ -13,10 +13,14 @@ from typing import (
     Any,
     Callable,
     Iterator,
-    NamedTuple,
 )
 
 # Local libraries
+from tracers.containers import (
+    DaemonResult,
+    Frame,
+    LoopSnapshot,
+)
 from tracers.contextvars import (
     LOGGER,
 )
@@ -76,11 +80,11 @@ def increase_counter(contextvar: ContextVar[int]) -> Iterator[None]:
 
 def json_dumps(element: object) -> str:
 
-    def encoder(obj: Any) -> Any:
-        if isinstance(obj, (list, set, tuple)):
-            casted_obj: Any = list(map(encoder, obj))
-        elif isinstance(obj, NamedTuple):
-            casted_obj = dict(zip(obj._fields, encoder(tuple(obj))))
+    def cast(obj: Any) -> Any:
+        if isinstance(obj, (DaemonResult, Frame, LoopSnapshot)):
+            casted_obj: Any = dict(zip(obj._fields, cast(tuple(obj))))
+        elif isinstance(obj, (list, set, tuple)):
+            casted_obj = list(map(cast, obj))
         elif isinstance(obj, Decimal):
             casted_obj = float(obj)
         else:
@@ -88,7 +92,7 @@ def json_dumps(element: object) -> str:
 
         return casted_obj
 
-    return json.dumps(element, default=encoder)
+    return json.dumps(cast(element))
 
 
 def log(*parts: str) -> None:
